<?php


namespace Drupal\ultimate_cron_views\Plugin\views\field;


use Drupal\Core\Form\FormStateInterface;
use Drupal\views\Plugin\views\field\FieldPluginBase;
use Drupal\views\ResultRow;

/**
 * Class CronLogJobEndDate
 *
 * @ViewsField("cron_log_job_end_date")
 */
class CronLogJobEndDate extends FieldPluginBase {

  /**
   * Define the available options
   * @return array
   */
  protected function defineOptions() {
    $options = parent::defineOptions();
    $options['precision'] = array('default' => 3);

    return $options;
  }

  /**
   * Provide the options form.
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {

    $options = [0, 1, 2, 3, 4];

    $form['precision'] = array(
      '#title' => $this->t('Select required precision for end time seconds.'),
      '#type' => 'select',
      '#default_value' => $this->options['precision'],
      '#options' => $options,
    );

    parent::buildOptionsForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function render(ResultRow $values) {

    $end_date = '';
    $precision = $this->options['precision'];

    if (isset($values->ultimate_cron_log_end_time)) {
      $end_time = number_format(round($values->ultimate_cron_log_end_time, $precision), $precision, '.', '');
      $end = explode('.', $end_time);
      $end_date = \Drupal::service('date.formatter')->format($end[0], 'custom', 'Y-m-d H:i:s');
      $end_date .= '.' . $end[1];
    }

    return [
      '#markup' => $end_date,
    ];

  }

  /**
   * Called to add the real field to a query.
   */
  public function query() {
    $this->realField = 'end_time';
    parent::query();
  }


}
